@@ -1,14 +1,29 @@
-import jnius_config
-jnius_config.add_classpath("../terrier-project-5.1-jar-with-dependencies.jar")
-from jnius import autoclass, cast
+# import jnius_config
+# jnius_config.add_classpath("../terrier-project-5.1-jar-with-dependencies.jar")
+# from jnius import autoclass, cast
 
 # import pytrec_eval
-import os, json
+import os, json, wget
 import numpy as np
 import pandas as pd
-from utils import *
-from batchretrieve import *
 
+def setup_terrier():
+    if not os.path.isfile("terrier-assemblies-5.1-jar-with-dependencies.jar"):
+        print('JAR file not found, downloading')
+        url = 'terrier-assemblies-5.1-jar-with-dependencies.jar'
+        wget.download(url, '.')
+    # import jnius_config
+    # jnius_config.add_classpath("./terrier-assemblies-5.1-jar-with-dependencies.jar")
+    # from jnius import autoclass, cast
+    # from utils import Utils
+    # from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
+
+setup_terrier()
+import jnius_config
+jnius_config.add_classpath("./terrier-assemblies-5.1-jar-with-dependencies.jar")
+from jnius import autoclass, cast
+from utils import Utils
+from batchretrieve import BatchRetrieve, FeaturesBatchRetrieve
 
 if __name__ == "__main__":
     JIR = autoclass('org.terrier.querying.IndexRef')
